 /*
 * file      : options_aacplusenc.c
 * project   : xcfa
 * with      : Gtk-2
 *
 * copyright : (C) 2003 - 2010 by Claude Bulin
 *
 * xcfa - GTK+ implementation of the GNU shell command
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#include <gtk/gtk.h>

#include <string.h>
#include "global.h"
#include "config_user.h"
#include "cd_audio.h"
#include "utils.h"
#include "options.h"
#include <stdlib.h>
#include <glib.h>
#include <glib/gstdio.h>
#include "info_song.h"

/*
*---------------------------------------------------------------------------
* VARIABLES
*---------------------------------------------------------------------------
*/

/*
*---------------------------------------------------------------------------
* CODE
*---------------------------------------------------------------------------
*/


/*  Christian Marillat
 *  mono   [ 12 .. 44 ] kbit
 *  stéréo [ 16 .. 64 ] kbit
 *
 *  Matteo Croce
 *  MONO   [ 10 12 14 18 20 24 32 40 ]
 *  STEREO [          18    24 32 40 48 ]
 *
*/
void optionsaacplusenc_combobox_accplusenc_mono_realize (GtkWidget *widget)
{
	utils_alloc_combo (GTK_COMBO_BOX (widget));
	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "10");
	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "12");
	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "14");
	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "18");
	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "20");
	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "24");
	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "32");
	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "40");
	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config_User.aacplusenc_choice_mono);
	var_options.Adr_Widget_aacplusenc_mono = GTK_COMBO_BOX (widget);
}

void optionsaacplusenc_combobox_accplusenc_stereo_realize (GtkWidget *widget)
{
	utils_alloc_combo (GTK_COMBO_BOX (widget));
	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "18");
	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "24");
	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "32");
	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "40");
	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "48");
	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config_User.aacplusenc_choice_stereo);
	var_options.Adr_Widget_aacplusenc_stereo = GTK_COMBO_BOX (widget);
}
	
gint optionsaacplusenc_get_bitrate_mono (void)
{
	gint	Tab [] = { 10, 12, 14, 18, 20, 24, 32, 40 };
	return (Tab [ gtk_combo_box_get_active (var_options.Adr_Widget_aacplusenc_mono) ]);
}

gint optionsaacplusenc_get_bitrate_stereo (void)
{
	gint	Tab [] = { 18, 24, 32, 40, 48 };
	return (Tab [ gtk_combo_box_get_active (var_options.Adr_Widget_aacplusenc_stereo) ]);
}


